[wise-commits] wise SVN: r581 - webgui/trunk/src/main/java/org/jboss/wise/gui/treeElement.

wise-commits at lists.jboss.org wise-commits at lists.jboss.org
Thu Jul 4 06:28:53 EDT 2013


Author: alessio.soldano at jboss.com
Date: 2013-07-04 06:28:53 -0400 (Thu, 04 Jul 2013)
New Revision: 581

Modified:
   webgui/trunk/src/main/java/org/jboss/wise/gui/treeElement/SimpleWiseTreeElement.java
Log:
Raise preview to 60 chars


Modified: webgui/trunk/src/main/java/org/jboss/wise/gui/treeElement/SimpleWiseTreeElement.java
===================================================================
--- webgui/trunk/src/main/java/org/jboss/wise/gui/treeElement/SimpleWiseTreeElement.java	2013-07-04 10:28:26 UTC (rev 580)
+++ webgui/trunk/src/main/java/org/jboss/wise/gui/treeElement/SimpleWiseTreeElement.java	2013-07-04 10:28:53 UTC (rev 581)
@@ -64,19 +64,19 @@
     }
 
     /**
      * This is the same as getValue except only the first 40 characters are
      * considered. This is needed to preview invocation results.
      * 
      * @return The substring(0,40) of the value
      */
     public String getShortValue() {
 	if (getValue() == null) {
 	    return null;
 	}
-	if (getValue().length() <= 40) {
+	if (getValue().length() <= 60) {
 	    return getValue();
 	}
-	return getValue().substring(0, 40) + "...";
+	return getValue().substring(0, 60) + "...";
     }
 
     /**
@@ -64,19 +64,19 @@
 
     /**
-     * This is the same as getValue except only the first 40 characters are
+     * This is the same as getValue except only the first 60 characters are
      * considered. This is needed to preview invocation results.
      * 
@@ -64,19 +64,19 @@
      * considered. This is needed to preview invocation results.
      * 
-     * @return The substring(0,40) of the value
+     * @return The substring(0,60) of the value
      */
     public String getShortValue() {



More information about the wise-commits mailing list